﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GridView;
using Telerik.Windows.Data;

namespace TicketID_258337_RowDetailsLazyLoad
{
    public partial class MainPage : UserControl
    {
        private readonly ViewModel viewModel;
        
        public MainPage()
        {
            InitializeComponent();

            this.viewModel = new ViewModel();
            this.clubsGrid.DataContext = this.viewModel;
            this.clubsGrid.DataLoaded += new System.EventHandler<System.EventArgs>(clubsGrid_DataLoaded);
        }

        void clubsGrid_DataLoaded(object sender, System.EventArgs e)
        {
            // Set the selected item after the data has been loaded!
            this.viewModel.SelectedClub = this.viewModel.Clubs[1];
        }

        public class ViewModel : INotifyPropertyChanged
        {
            public event PropertyChangedEventHandler PropertyChanged;

            private ObservableCollection<Club> clubs;
            private Club selectedClub;

            public ObservableCollection<Club> Clubs
            {
                get
                {
                    if (this.clubs == null)
                    {
                        this.clubs = Club.GetClubs();
                    }
                    
                    return this.clubs;
                }
            }

            public Club SelectedClub
            {
                get { return this.selectedClub; }
                set
                {
                    if (value != this.selectedClub)
                    {
                        this.selectedClub = value;
                        this.OnPropertyChanged("SelectedClub");
                    }
                }
            }

            protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
            {
                PropertyChangedEventHandler handler = this.PropertyChanged;
                if (handler != null)
                {
                    handler(this, args);
                }
            }

            private void OnPropertyChanged(string propertyName)
            {
                this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}